#[non_exhaustive]pub enum NumericComparisonError {
LeftMissing {
declared: DataType,
},
RightMissing {
declared: DataType,
},
LeftNotNumeric {
actual: DataType,
},
RightNotNumeric {
actual: DataType,
},
LeftNaN,
RightNaN,
BothNaN,
}Expand description
Describes why two crate::Value instances cannot be numerically ordered.
Examples
use qubit_datatype::NumericComparisonPolicy;
use qubit_value::{NumericComparisonError, Value};
let error = Value::from("text")
.numeric_cmp(&Value::from(1_i32), NumericComparisonPolicy::Exact)
.unwrap_err();
assert!(matches!(error, NumericComparisonError::LeftNotNumeric { .. }));Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
LeftMissing
The left operand is unset but retains a declared type.
RightMissing
The right operand is unset but retains a declared type.
LeftNotNumeric
The concrete left operand is not numeric.
RightNotNumeric
The concrete right operand is not numeric.
LeftNaN
Only the left operand is NaN.
RightNaN
Only the right operand is NaN.
BothNaN
Both operands are NaN.