#[non_exhaustive]pub enum ValueMissingReason {
UnsetScalar,
UnsetCollection,
EmptyCollection,
Conversion,
}Expand description
Identifies why a read could not produce a concrete value.
The reason is independent of the source and target types. Inspect the
accompanying crate::ValueMissing accessors for those types and for a
collection index when one is available.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnsetScalar
Scalar storage is unset with a declared type.
UnsetCollection
Collection storage is unset with a declared element type.
EmptyCollection
A concrete collection has no first item.
Conversion
Conversion policy classified a concrete scalar or collection item as missing.