Module multi_values

Module multi_values 

Multiple Values Module

Public entry for multiple-values container implementations.

Enums

MultiValues
Multiple values container

Traits

MultiValuesAddArg
Internal dispatch trait for MultiValues::add<S>().
MultiValuesAdder
Internal trait used to add a single value to MultiValues.
MultiValuesConstructor
Internal trait used to create MultiValues from Vec<T>.
MultiValuesConstructorArg
Internal dispatch trait for MultiValues::new<S>() arguments.
MultiValuesFirstGetter
Internal trait used to extract the first value from MultiValues.
MultiValuesGetter
Internal trait used to extract multiple values from MultiValues.
MultiValuesMultiAdder
Internal trait used to add multiple values to MultiValues.
MultiValuesSetArg
Internal dispatch trait for MultiValues::set<S>().
MultiValuesSetter
Internal trait used to set specific value lists in MultiValues.
MultiValuesSetterSlice
Internal trait used to set MultiValues from a slice.
MultiValuesSingleSetter
Internal trait used to set a single value in MultiValues.