pub trait MultiValuesSetterSlice<T>: MultiValuesSetterSliceSealed<T> {
// Required method
fn set_values_slice(&mut self, values: &[T]) -> ValueResult<()>;
}Expand description
Internal trait used to set MultiValues from a slice.
This trait backs MultiValues::set<S>(); downstream code should call the
inherent method instead of implementing or naming this trait directly.
Required Methods
Sourcefn set_values_slice(&mut self, values: &[T]) -> ValueResult<()>
fn set_values_slice(&mut self, values: &[T]) -> ValueResult<()>
Replaces the stored values with a clone of values.
Returns
Returns Ok(()) when the values can be stored, or a ValueError
describing why the update failed.