IntoValueDefault

Trait IntoValueDefault 

pub trait IntoValueDefault<T> {
    // Required method
    fn into_value_default(self) -> T;
}
Converts ergonomic default arguments into the value type expected by a read API.

Type Parameters

  • T - Owned default type required by the read operation.

Examples

use qubit_value::IntoValueDefault;

let owned: String = "fallback".into_value_default();
assert_eq!(owned, "fallback");

Required Methods

fn into_value_default(self) -> T

Converts this argument into the default value.

Returns

The owned default value expected by the read API.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IntoValueDefault<String> for &String

Source

impl IntoValueDefault<String> for &str

Source

impl IntoValueDefault<Vec<String>> for &Vec<&str>

Source

impl IntoValueDefault<Vec<String>> for &[&str]

Source

impl IntoValueDefault<Vec<String>> for Vec<&str>

Source

impl<T, const N: usize> IntoValueDefault<Vec<T>> for &[T; N]
where T: Clone,

Source

impl<T, const N: usize> IntoValueDefault<Vec<T>> for [T; N]

Source

impl<T> IntoValueDefault<Vec<T>> for &Vec<T>
where T: Clone,

Source

impl<T> IntoValueDefault<Vec<T>> for &[T]
where T: Clone,

Source

impl<const N: usize> IntoValueDefault<Vec<String>> for &[&str; N]

Source

impl<const N: usize> IntoValueDefault<Vec<String>> for [&str; N]

Implementors

Source

impl<T> IntoValueDefault<T> for T