ValueWireDecodeError

Enum ValueWireDecodeError 

#[non_exhaustive]
pub enum ValueWireDecodeError { Budget(BudgetError<JsonResource, usize>), Quantity { resource: JsonResource, source: QuantityConversionError, }, Syntax(JsonSyntaxError), UnsupportedVersion { expected: u8, actual: u8, }, InvalidJson(Error), }
Error produced by a bounded crate::ValueWireV1 JSON decoder.

Examples

use qubit_value::{ValueWireDecodeError, ValueWireV1};

let error = ValueWireV1::decode_json_slice(b"{").unwrap_err();
assert!(matches!(
    error,
    ValueWireDecodeError::Syntax(_) | ValueWireDecodeError::InvalidJson(_)
));

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Budget(BudgetError<JsonResource, usize>)

The JSON document exceeded one configured resource budget.

Tuple Fields

0: BudgetError<JsonResource, usize>

Budget violation reported by the bounded JSON decoder.



Quantity

A native JSON measurement could not be represented by the budget quantity type.

Fields

resource: JsonResource

Resource whose measurement failed.

source: QuantityConversionError

Native measurement conversion failure.



Syntax(JsonSyntaxError)

The bounded input contains JSON syntax errors with source location.

Tuple Fields

0: JsonSyntaxError

Syntax error with its source location preserved.



UnsupportedVersion

The envelope declares a wire version that this decoder does not support.

Fields

expected: u8

Wire version accepted by this decoder.

actual: u8

Wire version declared by the input envelope.



InvalidJson(Error)

The bounded input is not a valid V1 JSON wire value.

Tuple Fields

0: Error

Serde JSON error stripped of input contents but retaining location.