#[non_exhaustive]pub enum ValueWireEncodeError {
NonFiniteFloat {
data_type: DataType,
},
BigDecimalScaleTooLarge {
scale: i64,
maximum_absolute_scale: i64,
},
ReservedJsonObjectKey {
key: &'static str,
},
}Expand description
A runtime value cannot be represented by the JSON V1 wire contract.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NonFiniteFloat
A JSON V1 float must be finite.
BigDecimalScaleTooLarge
A V1 decimal exponent must stay within the bounded wire range.
Fields
ReservedJsonObjectKey
A JSON V1 object uses serde_json’s private number marker key.