Multiple Values Module
Public entry for multiple-values container implementations.
Enums
- Multi
Values - Multiple values container
Traits
- Multi
Values AddArg - Internal dispatch trait for
MultiValues::add<S>(). - Multi
Values Adder - Internal trait used to add a single value to
MultiValues. - Multi
Values Constructor - Internal trait used to create
MultiValuesfromVec<T>. - Multi
Values Constructor Arg - Internal dispatch trait for
MultiValues::new<S>()arguments. - Multi
Values First Getter - Internal trait used to extract the first value from
MultiValues. - Multi
Values Getter - Internal trait used to extract multiple values from
MultiValues. - Multi
Values Multi Adder - Internal trait used to add multiple values to
MultiValues. - Multi
Values SetArg - Internal dispatch trait for
MultiValues::set<S>(). - Multi
Values Setter - Internal trait used to set specific value lists in
MultiValues. - Multi
Values Setter Slice - Internal trait used to set
MultiValuesfrom a slice. - Multi
Values Single Setter - Internal trait used to set a single value in
MultiValues.